#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"


/* ************************************ */

/*
Install a signal handler for the EVENT signal for
each of the widgets in the test application.
Print out the event type and widget name from the
signal handler for debugging purposes.
*/

/* ************************************ */

void print_event(GtkWidget *widget,GdkEvent *event)
{
  char* eventType;

  switch (event->type) {
    case GDK_NOTHING:
      eventType="GDK_NOTHING";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_DELETE:
      eventType="GDK_DELETE";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_DESTROY:
      eventType="GDK_DESTROY";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_EXPOSE:
      eventType="GDK_EXPOSE";
/*      printf("%16s : event type : %s\n",widget->name,eventType); */
      break;
    case GDK_MOTION_NOTIFY:
      eventType="GDK_MOTION_NOTIFY";
/*      printf("%16s : event type : %s\n",widget->name,eventType); */
      break;
    case GDK_BUTTON_PRESS:
      eventType="GDK_BUTTON_PRESS";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_2BUTTON_PRESS:
      eventType="GDK_2BUTTON_PRESS";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_3BUTTON_PRESS:
      eventType="GDK_3BUTTON_PRESS";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_BUTTON_RELEASE:
      eventType="GDK_BUTTON_RELEASE";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_KEY_PRESS:
      eventType="GDK_KEY_PRESS";
      printf("%16s : event type : %s : keyval=%d\n",widget->name,eventType,event->key.keyval);
      break;
    case GDK_KEY_RELEASE:
      eventType="GDK_KEY_RELEASE";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_ENTER_NOTIFY:
      eventType="GDK_ENTER_NOTIFY";
/*      printf("%16s : event type : %s\n",widget->name,eventType); */
      break;
    case GDK_LEAVE_NOTIFY:
      eventType="GDK_LEAVE_NOTIFY";
/*      printf("%16s : event type : %s\n",widget->name,eventType); */
      break;
    case GDK_FOCUS_CHANGE:
      if (event->focus_change.in)
        eventType="GDK_FOCUS_CHANGE (in)";
      else
        eventType="GDK_FOCUS_CHANGE (out)";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_CONFIGURE:
      eventType="GDK_CONFIGURE";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_MAP:
      eventType="GDK_MAP";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_UNMAP:
      eventType="GDK_UNMAP";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_PROPERTY_NOTIFY:
      eventType="GDK_PROPERTY_NOTIFY";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_SELECTION_CLEAR:
      eventType="GDK_SELECTION_CLEAR";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_SELECTION_REQUEST:
      eventType="GDK_SELECTION_REQUEST";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_SELECTION_NOTIFY:
      eventType="GDK_SELECTION_NOTIFY";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_PROXIMITY_IN:
      eventType="GDK_PROXIMITY_IN";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_PROXIMITY_OUT:
      eventType="GDK_PROXIMITY_OUT";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_DRAG_ENTER:
      eventType="GDK_DRAG_ENTER";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_DRAG_LEAVE:
      eventType="GDK_DRAG_LEAVE";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_DRAG_MOTION:
      eventType="GDK_DRAG_MOTION";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_DRAG_STATUS:
      eventType="GDK_DRAG_STATUS";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_DROP_START:
      eventType="GDK_DROP_START";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_DROP_FINISHED:
      eventType="GDK_DROP_FINISHED";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_CLIENT_EVENT:
      eventType="GDK_CLIENT_EVENT";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_VISIBILITY_NOTIFY:
      eventType="GDK_VISIBILITY_NOTIFY";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_NO_EXPOSE:
      eventType="GDK_NO_EXPOSE";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_SCROLL:
      eventType="GDK_SCROLL";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_WINDOW_STATE:
      eventType="GDK_WINDOW_STATE";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    case GDK_SETTING:
      eventType="GDK_SETTING";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
    default:
      eventType="default";
      printf("%16s : event type : %s\n",widget->name,eventType);
      break;
  }
}

/* ************************************ */

gboolean
on_entry1_event                        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_entry2_event                        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_checkbutton5_event                  (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_checkbutton3_event                  (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_label1_event                        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_combo1_event                        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_combo_entry1_event                  (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_checkbutton4_event                  (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_spinbutton1_event                   (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_label2_event                        (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_treeview1_event                     (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_checkbutton2_event                  (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}


gboolean
on_checkbutton1_event                  (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}

gboolean
on_notebook1_event                     (GtkWidget       *widget,
                                        GdkEvent        *event,
                                        gpointer         user_data)
{
  print_event(widget,event);
  return FALSE;
}

void
on_window1_destroy                     (GtkObject       *object,
                                        gpointer         user_data)
{
  gtk_main_quit() ;
}



